# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.getmessagelistforspecificthread_response import GetmessagelistforspecificthreadResponse
from apimaticcalculatorlatest.models.getmessagethreads_response import GetmessagethreadsResponse
from apimaticcalculatorlatest.models.api_responsewithout_data import APIResponsewithoutData

class TestingOfMessageAPICallsController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def get_testmessagelistforspecificthread(self,
                                             thread_id):
        """Does a GET request to /messageTest/specificthread/{threadId}.

        Since API calls for messages depend on channel connections and these
        values will exist in BookingPal only if guests on channel create some
        message, these calls can work only on production. So for testing
        purposes, we’ve built an additional endpoint with the same API calls
        where you will be able to test these calls.
        This function allows the logged-in user to get a list of all messages
        from passed thread Id. You need to use PM credentials
        Note: To be able to test these calls, you need to have at least 1
        property, since we will in response return you messages for 1 property
        from your PM.

        Args:
            thread_id (string): ID of thread

        Returns:
            GetmessagelistforspecificthreadResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/messageTest/specificthread/{threadId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'threadId': thread_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetmessagelistforspecificthreadResponse.from_dictionary)

    def get_testmessagethreads(self,
                               page,
                               limit,
                               thread_type):
        """Does a GET request to /messageTest/allthreads/{threadType}.

        This function allows the logged in user to get all message threads or
        message threads with an unresponded message from guest for the whole
        PM. You need to use PM credentials. There is also paging as optional
        values. If you do not pass this value, we will return the first page
        and 10 threads per page.
        Since API calls for messages depend on channel connections and these
        values will exist in BookingPal only if guests on channel create some
        message, these calls can work only on production. So for testing
        purposes we’ve  built an additional endpoint with the same API calls
        where you will be able to test these calls.
        Note: To be able to test these calls, you need to have at least 1
        property, since we will in response return you messages for 1 property
        from your PM.

        Args:
            page (int): TODO: type description here. Example: 
            limit (int): TODO: type description here. Example: 
            thread_type (string): Request all threads or only threads with
                unanswered message {new,all}

        Returns:
            GetmessagethreadsResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/messageTest/allthreads/{threadType}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'threadType': thread_type
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'page': page,
            'limit': limit
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetmessagethreadsResponse.from_dictionary)

    def postnew_testmessageforspecificthread(self,
                                             body):
        """Does a POST request to /messageTest.

        This function will allow PM to post new messages in already existing
        threads. Since this call is only for testing - we will not actually
        save these passed values.
        Since API calls for messages depend on channel connections and these
        values will exist in BookingPal only if guests on channel create some
        message, these calls can work only on production. So for testing
        purposes, we’ve built an additional endpoint with the same API calls
        where you will be able to test these calls.
        Note: To be able to test these calls, you need to have at least 1
        property, since we will in response return to you messages for 1
        property from your PM.

        Args:
            body (PostnewmessageforspecificthreadRequest): TODO: type
                description here. Example: 

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/messageTest'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Text(object):

    """Implementation of the 'Text' model.

    TODO: type model description here.

    Attributes:
        language (string): Language 2 letter value  as ISO 639-1 code
            (https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes)
        value (string): Text value. Send here only plain text. Do not use HTML
            or any other characters.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "language":'language',
        "value":'value'
    }

    def __init__(self,
                 language=None,
                 value=None):
        """Constructor for the Text class"""

        # Initialize members of the class
        self.language = language
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        language = dictionary.get('language')
        value = dictionary.get('value')

        # Return an object of this model
        return cls(language,
                   value)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.asynchronous_validationmodel

class ValidationAsynchronouspushmessagerequest(object):

    """Implementation of the 'ValidationAsynchronouspushmessagerequest' model.

    Request for validation messages which BookingPal push asynchronous
    (webhooks request)

    Attributes:
        supplier_id (int): Id of supplier in BookingPal
        mtype (string): TODO: type description here.
        validation (list of AsynchronousValidationmodel): Validation Model

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "supplier_id":'supplierId',
        "mtype":'type',
        "validation":'validation'
    }

    def __init__(self,
                 supplier_id=None,
                 mtype='BP_VALIDATION',
                 validation=None):
        """Constructor for the ValidationAsynchronouspushmessagerequest class"""

        # Initialize members of the class
        self.supplier_id = supplier_id
        self.mtype = mtype
        self.validation = validation


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        supplier_id = dictionary.get('supplierId')
        mtype = dictionary.get("type") if dictionary.get("type") else 'BP_VALIDATION'
        validation = None
        if dictionary.get('validation') != None:
            validation = list()
            for structure in dictionary.get('validation'):
                validation.append(apimaticcalculatorlatest.models.asynchronous_validationmodel.AsynchronousValidationmodel.from_dictionary(structure))

        # Return an object of this model
        return cls(supplier_id,
                   mtype,
                   validation)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class FeeUnitEnum(object):

    """Implementation of the 'FeeUnitEnum' enum.

    TODO: type enum description here.

    Attributes:
        PER_STAY: TODO: type description here.
        PER_DAY: TODO: type description here.
        PER_PERSON: TODO: type description here.
        PER_DAY_PER_PERSON: TODO: type description here.
        PER_DAY_PER_PERSON_EXTRA: TODO: type description here.

    """

    PER_STAY = 'PER_STAY'

    PER_DAY = 'PER_DAY'

    PER_PERSON = 'PER_PERSON'

    PER_DAY_PER_PERSON = 'PER_DAY_PER_PERSON'

    PER_DAY_PER_PERSON_EXTRA = 'PER_DAY_PER_PERSON_EXTRA'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AllowedPetsTypeEnum(object):

    """Implementation of the 'AllowedPetsTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        ALLOWED: TODO: type description here.
        ALLOWEDONREQUEST: TODO: type description here.
        NOTALLOWED: TODO: type description here.

    """

    ALLOWED = 'Allowed'

    ALLOWEDONREQUEST = 'AllowedOnRequest'

    NOTALLOWED = 'NotAllowed'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.credit_card

class Payment(object):

    """Implementation of the 'Payment' model.

    TODO: type model description here.

    Attributes:
        payment_type (PaymentTypeEnum): TODO: type description here.
        credit_card (CreditCard): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_type":'paymentType',
        "credit_card":'creditCard'
    }

    def __init__(self,
                 payment_type=None,
                 credit_card=None):
        """Constructor for the Payment class"""

        # Initialize members of the class
        self.payment_type = payment_type
        self.credit_card = credit_card


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_type = dictionary.get('paymentType')
        credit_card = apimaticcalculatorlatest.models.credit_card.CreditCard.from_dictionary(dictionary.get('creditCard')) if dictionary.get('creditCard') else None

        # Return an object of this model
        return cls(payment_type,
                   credit_card)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.message_model

class MessagesModel(object):

    """Implementation of the 'MessagesModel' model.

    List of messages Model

    Attributes:
        messages (list of MessageModel): List of models

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "messages":'messages'
    }

    def __init__(self,
                 messages=None):
        """Constructor for the MessagesModel class"""

        # Initialize members of the class
        self.messages = messages


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        messages = None
        if dictionary.get('messages') != None:
            messages = list()
            for structure in dictionary.get('messages'):
                messages.append(apimaticcalculatorlatest.models.message_model.MessageModel.from_dictionary(structure))

        # Return an object of this model
        return cls(messages)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.fee_tax_mandatory_setting

class FeeTaxValidationSettings(object):

    """Implementation of the 'FeeTaxValidationSettings' model.

    TODO: type model description here.

    Attributes:
        validation_settings (list of FeeTaxMandatorySetting): Model

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "validation_settings":'validationSettings'
    }

    def __init__(self,
                 validation_settings=None):
        """Constructor for the FeeTaxValidationSettings class"""

        # Initialize members of the class
        self.validation_settings = validation_settings


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        validation_settings = None
        if dictionary.get('validationSettings') != None:
            validation_settings = list()
            for structure in dictionary.get('validationSettings'):
                validation_settings.append(apimaticcalculatorlatest.models.fee_tax_mandatory_setting.FeeTaxMandatorySetting.from_dictionary(structure))

        # Return an object of this model
        return cls(validation_settings)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.beds

class Bedroom(object):

    """Implementation of the 'Bedroom' model.

    TODO: type model description here.

    Attributes:
        beds (Beds): TODO: type description here.
        mtype (BedroomTypeEnum): TODO: type description here.
        private_bathroom (bool): Room have private bathroom

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "beds":'beds',
        "mtype":'type',
        "private_bathroom":'privateBathroom'
    }

    def __init__(self,
                 beds=None,
                 mtype=None,
                 private_bathroom=None):
        """Constructor for the Bedroom class"""

        # Initialize members of the class
        self.beds = beds
        self.mtype = mtype
        self.private_bathroom = private_bathroom


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        beds = apimaticcalculatorlatest.models.beds.Beds.from_dictionary(dictionary.get('beds')) if dictionary.get('beds') else None
        mtype = dictionary.get('type')
        private_bathroom = dictionary.get('privateBathroom')

        # Return an object of this model
        return cls(beds,
                   mtype,
                   private_bathroom)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ReservationFeeNotificationModel(object):

    """Implementation of the 'ReservationFeeNotificationModel' model.

    Model used for fees in reservation push notification

    Attributes:
        id (string): Fee altID (alt ID which PMS sent over API)
        name (string): Fee name
        value (float): Fee value

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "value":'value',
        "id":'id'
    }

    def __init__(self,
                 name=None,
                 value=None,
                 id=None):
        """Constructor for the ReservationFeeNotificationModel class"""

        # Initialize members of the class
        self.id = id
        self.name = name
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        value = dictionary.get('value')
        id = dictionary.get('id')

        # Return an object of this model
        return cls(name,
                   value,
                   id)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.productresponse import Productresponse
from apimaticcalculatorlatest.models.api_responsewithout_data import APIResponsewithoutData

class ProductController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def updateproduct(self,
                      content_type,
                      body):
        """Does a PUT request to /product.

        This function allows a logged in user to update product details.
        Request parameters and request example will be the same as in the
        create product API. The only field that must be added is the product
        id.
        You need to have all other parameters which were used in the create
        API call that you want to keep (AltID can’t be updated). Everything
        that you do not send as an update will be deleted (overwritten).
        Response parameters and response examples are the same as in the
        create product API.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (CreateUpdatePropertyRequest): TODO: type description here.
                Example: 

        Returns:
            Productresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/product'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, Productresponse.from_dictionary)

    def createproduct(self,
                      content_type,
                      body):
        """Does a POST request to /product.

        This function allows a logged in user to create new product. You can
        only send one product in each request. 

        Args:
            content_type (string): TODO: type description here. Example: 
            body (CreateUpdatePropertyRequest): TODO: type description here.
                Example: 

        Returns:
            Productresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/product'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, Productresponse.from_dictionary)

    def deletelistproduct(self,
                          content_type,
                          body):
        """Does a DELETE request to /product.

        This function allows logged in user to delete list of products.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (PropertyListRequest): TODO: type description here. Example:
                
        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/product'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def create_activationlistproduct(self,
                                     content_type,
                                     body):
        """Does a POST request to /product/activation.

        This function allows logged in user to activate a list of products in
        BookingPal. Products MUST be activated successfully before they can be
        distributed to any channel. 
        Note: When a product is successfully activated it will be queued for
        the internal BP validation function and you will receive async push
        messages when the validation is completed - like it is described in
        the Validation section.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (PropertyListRequest): TODO: type description here. Example:
                
        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/product/activation'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def deleteproduct(self,
                      product_id):
        """Does a DELETE request to /product/{productId}.

        This function allows the logged in user to delete product.

        Args:
            product_id (string): Property ID

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/product/{productId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'productId': product_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def getproductlist(self):
        """Does a GET request to /product.

        This API call will return a list of properties that belong to the
        current user. This means that a user has to be logged in with products
        created already.
        Every API call in this section should be with PM credentials.

        Returns:
            Productresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/product'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, Productresponse.from_dictionary)

    def create_deactivationlistproduct(self,
                                       content_type,
                                       body):
        """Does a POST request to /product/deactivation.

        This function allows the logged in user to deactivate a list of
        products. This function will also close the calendars on every channel
        the products have been listed on.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (PropertyListRequest): TODO: type description here. Example:
                
        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/product/deactivation'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def getproductby_id(self,
                        product_id):
        """Does a GET request to /product/{productId}.

        This function allows logged in user to get a specific product.

        Args:
            product_id (string): Id of the property

        Returns:
            Productresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/product/{productId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'productId': product_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, Productresponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.fee
import apimaticcalculatorlatest.models.taxes

class FeeTax(object):

    """Implementation of the 'FeeTax' model.

    TODO: type model description here.

    Attributes:
        product_id (int): ID of the product
        fees (list of Fee): List of models
        taxes (list of Taxes): List of models

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_id":'productId',
        "fees":'fees',
        "taxes":'taxes'
    }

    def __init__(self,
                 product_id=None,
                 fees=None,
                 taxes=None):
        """Constructor for the FeeTax class"""

        # Initialize members of the class
        self.product_id = product_id
        self.fees = fees
        self.taxes = taxes


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        product_id = dictionary.get('productId')
        fees = None
        if dictionary.get('fees') != None:
            fees = list()
            for structure in dictionary.get('fees'):
                fees.append(apimaticcalculatorlatest.models.fee.Fee.from_dictionary(structure))
        taxes = None
        if dictionary.get('taxes') != None:
            taxes = list()
            for structure in dictionary.get('taxes'):
                taxes.append(apimaticcalculatorlatest.models.taxes.Taxes.from_dictionary(structure))

        # Return an object of this model
        return cls(product_id,
                   fees,
                   taxes)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class RequestToBookCancelRequestModel(object):

    """Implementation of the 'RequestToBookCancelRequestModel' model.

    Model for request to book cancel API request

    Attributes:
        action (string): RESERVATION_REQUEST_VOIDED
        reservation_id (int): ID of reservation in BookingPal

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "action":'action',
        "reservation_id":'reservationId'
    }

    def __init__(self,
                 action=None,
                 reservation_id=None):
        """Constructor for the RequestToBookCancelRequestModel class"""

        # Initialize members of the class
        self.action = action
        self.reservation_id = reservation_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        action = dictionary.get('action')
        reservation_id = dictionary.get('reservationId')

        # Return an object of this model
        return cls(action,
                   reservation_id)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class PaymentPolicyTypeEnum(object):

    """Implementation of the 'PaymentPolicyTypeEnum' enum.

    Full or Split payment. In case of Split payment - it will be 2 payments.
    [SPLIT,FULL]

    Attributes:
        SPLIT: TODO: type description here.
        FULL: TODO: type description here.

    """

    SPLIT = 'SPLIT'

    FULL = 'FULL'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Location(object):

    """Implementation of the 'Location' model.

    TODO: type model description here.

    Attributes:
        postal_code (string): Postal code of property (Zip code)
        country (string): Country of property. Require 2 letter ISO code
        region (string): State (Region) of PM. Required for US properties.
        city (string): City of property
        street (string): Street of property
        zip_code_9 (string): Set only for US properties (format should be
            zip5-xxxx)

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "postal_code":'postalCode',
        "country":'country',
        "region":'region',
        "city":'city',
        "street":'street',
        "zip_code_9":'zipCode9'
    }

    def __init__(self,
                 postal_code=None,
                 country=None,
                 region=None,
                 city=None,
                 street=None,
                 zip_code_9=None):
        """Constructor for the Location class"""

        # Initialize members of the class
        self.postal_code = postal_code
        self.country = country
        self.region = region
        self.city = city
        self.street = street
        self.zip_code_9 = zip_code_9


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        postal_code = dictionary.get('postalCode')
        country = dictionary.get('country')
        region = dictionary.get('region')
        city = dictionary.get('city')
        street = dictionary.get('street')
        zip_code_9 = dictionary.get('zipCode9')

        # Return an object of this model
        return cls(postal_code,
                   country,
                   region,
                   city,
                   street,
                   zip_code_9)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.lo_sratesresponse import LOSratesresponse

class LOSPricingController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def createandupdate_los_lengthof_stay_pricing(self,
                                                  content_type,
                                                  body):
        """Does a POST request to /losrates.

        Introduction: You can use this function if you would like to send
        BookingPal different prices for various Length of Stays with the same
        starting date.
        LOS Pricing will be a different method in sending rates to BookingPal
        and is defined as pricing sent for a specific “Stay ranges”, In the
        LOS  method you are setting specific rates based on the Length of
        Stay. (This is a different way to push rates to BookingPal. )
        For date periods of 1 to 30 days a specific rate need to enter
        check-in date and a rate for every possible reservation starting at
        that date (i.e. 1 day, 2 days, up to 30 days, 30 days is the maximum
        value allowed for this field) you will need to send BookingPal total
        rate value for that period. 
        Maximum LOS number of days is 30. All other LOS values after 30 will
        not be saved. If you do not support reservation for some specific
        number of dates - send value 0.00 for this LOS number of days. Keep in
        mind that all values not sent for any specific check-in date will be
        considered as 0, and reservation for this number of days will not be
        possible.
        Field maxGuests allows you to set different rates per different number
        of guests. If you do not have different rate values per number of
        guests - you can send the value for maximum number of guests, and all
        others will have the same rate.
        For MLT properties which supported LOS price for update number of
        count you can use it rates and availability API.
        It is suggested to manage availability over “rates and availability”
        API call, and to close/open dates over this call.
        Note: this API call can be used only if you set supportedLosRates =
        true on the product. Otherwise using this API for specific product is
        not possible.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (CreateandupdateLOSRequest): TODO: type description here.
                Example: 

        Returns:
            LOSratesresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/losrates'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, LOSratesresponse.from_dictionary)

    def getlospriceslistbyproduct_id(self,
                                     product_id):
        """Does a GET request to /losrates/{productId}.

        This function allows the logged in user to get a LOS rate for
        property.

        Args:
            product_id (string): Property ID in BookingPal

        Returns:
            LOSratesresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/losrates/{productId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'productId': product_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, LOSratesresponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ReservationParkingTypeEnum(object):

    """Implementation of the 'ReservationParkingTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        NORESERVATIONNEEDED: TODO: type description here.
        NOTPOSSIBLE: TODO: type description here.
        RESERVATIONNEEDED: TODO: type description here.

    """

    NORESERVATIONNEEDED = 'NoReservationNeeded'

    NOTPOSSIBLE = 'NotPossible'

    RESERVATIONNEEDED = 'ReservationNeeded'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class RequesttoBookTestActionEnum(object):

    """Implementation of the 'RequesttoBookTestActionEnum' enum.

    Allowed values for request to book Test action

    Attributes:
        RESERVATION_REQUEST_VOIDED: TODO: type description here.
        RESERVATION_REQUEST: TODO: type description here.

    """

    RESERVATION_REQUEST_VOIDED = 'RESERVATION_REQUEST_VOIDED'

    RESERVATION_REQUEST = 'RESERVATION_REQUEST'




__all__ = [
    'base_controller',
    'product_controller',
    'los_pricing_controller',
    'messaging_controller',
    'property_managers_controller',
    'request_to_book_controller',
    'images_controller',
    'fee_and_tax_mandatory_at_the_property_level_controller',
    'yields_controller',
    'fee_and_tax_controller',
    'validation_controller',
    'push_notification_controller',
    'rates_and_availability_controller',
    'reservation_notifications_controller',
    'testing_of_message_api_calls_controller',
    'authorization_controller',
]


# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.company

class PropertyManagerdetailsresponse(object):

    """Implementation of the 'PropertyManagerdetailsresponse' model.

    TODO: type model description here.

    Attributes:
        message (string): text info message
        error_message (list of string): List of error messages
        is_error (bool): Is error (default = false)
        code (string): Code of message
        data (list of Company): List of models

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "message":'message',
        "error_message":'errorMessage',
        "is_error":'is_error',
        "code":'code',
        "data":'data'
    }

    def __init__(self,
                 message=None,
                 error_message=None,
                 is_error=None,
                 code=None,
                 data=None):
        """Constructor for the PropertyManagerdetailsresponse class"""

        # Initialize members of the class
        self.message = message
        self.error_message = error_message
        self.is_error = is_error
        self.code = code
        self.data = data


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        message = dictionary.get('message')
        error_message = dictionary.get('errorMessage')
        is_error = dictionary.get('is_error')
        code = dictionary.get('code')
        data = None
        if dictionary.get('data') != None:
            data = list()
            for structure in dictionary.get('data'):
                data.append(apimaticcalculatorlatest.models.company.Company.from_dictionary(structure))

        # Return an object of this model
        return cls(message,
                   error_message,
                   is_error,
                   code,
                   data)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser
import apimaticcalculatorlatest.models.reservationnotificationobject

class RequestToBookRequestModel(object):

    """Implementation of the 'RequestToBookRequestModel' model.

    Model for request to book API request

    Attributes:
        rezcaster_notification_request (Reservationnotificationobject): TODO:
            type description here.
        action (string): RESERVATION_REQUEST
        reservation_id (int): ID of reservation in BookingPal
        message_to_host (string): Message from Guest to host
        expires_at (date): expires time. Date is in format "yyyy-MM-dd"

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "rezcaster_notification_request":'rezcasterNotificationRequest',
        "action":'action',
        "reservation_id":'reservationId',
        "expires_at":'expires_at',
        "message_to_host":'messageToHost'
    }

    def __init__(self,
                 rezcaster_notification_request=None,
                 action=None,
                 reservation_id=None,
                 expires_at=None,
                 message_to_host=None):
        """Constructor for the RequestToBookRequestModel class"""

        # Initialize members of the class
        self.rezcaster_notification_request = rezcaster_notification_request
        self.action = action
        self.reservation_id = reservation_id
        self.message_to_host = message_to_host
        self.expires_at = expires_at


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        rezcaster_notification_request = apimaticcalculatorlatest.models.reservationnotificationobject.Reservationnotificationobject.from_dictionary(dictionary.get('rezcasterNotificationRequest')) if dictionary.get('rezcasterNotificationRequest') else None
        action = dictionary.get('action')
        reservation_id = dictionary.get('reservationId')
        expires_at = dateutil.parser.parse(dictionary.get('expires_at')).date() if dictionary.get('expires_at') else None
        message_to_host = dictionary.get('messageToHost')

        # Return an object of this model
        return cls(rezcaster_notification_request,
                   action,
                   reservation_id,
                   expires_at,
                   message_to_host)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper


class Configuration(object):

    """A class used for configuring the SDK by a user.

    This class need not be instantiated and all properties and methods
    are accessible without instance creation.

    """

    # Set the array parameter serialization method
    # (allowed: indexed, unindexed, plain, csv, tsv, psv)
    array_serialization = "indexed"

    # The base Uri for API calls
    base_uri = 'https://apidemo.mybookingpal.com'

    # Token which need to be passed in every request as GET parameter. You will
    # get this token in authorization response. Token is valid 1 hour.
    # TODO: Set an appropriate value
    jwt = None




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TaxisTypeEnum(object):

    """Implementation of the 'TaxisTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        SALESTAXINCLUDED: TODO: type description here.
        SALESTAXEXCLUDED: TODO: type description here.

    """

    SALESTAXINCLUDED = 'SalesTaxIncluded'

    SALESTAXEXCLUDED = 'SalesTaxExcluded'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.manual_policy

class CancellationPolicy(object):

    """Implementation of the 'CancellationPolicy' model.

    TODO: type model description here.

    Attributes:
        mtype (CancellationPolicyTypeEnum): TODO: type description here.
        manual_policy (ManualPolicy): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype":'type',
        "manual_policy":'manualPolicy'
    }

    def __init__(self,
                 mtype=None,
                 manual_policy=None):
        """Constructor for the CancellationPolicy class"""

        # Initialize members of the class
        self.mtype = mtype
        self.manual_policy = manual_policy


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype = dictionary.get('type')
        manual_policy = apimaticcalculatorlatest.models.manual_policy.ManualPolicy.from_dictionary(dictionary.get('manualPolicy')) if dictionary.get('manualPolicy') else None

        # Return an object of this model
        return cls(mtype,
                   manual_policy)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser

class AvailableCount(object):

    """Implementation of the 'AvailableCount' model.

    TODO: type model description here.

    Attributes:
        begin_date (date): Beginning date of date range for which count is
            applied. Date should be in format "yyyy-MM-dd"
        end_date (date): End date of date range for which count  is applied.
            Date should be in format "yyyy-MM-dd"
        count (int): Number of available rooms

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "begin_date":'beginDate',
        "end_date":'endDate',
        "count":'count'
    }

    def __init__(self,
                 begin_date=None,
                 end_date=None,
                 count=None):
        """Constructor for the AvailableCount class"""

        # Initialize members of the class
        self.begin_date = begin_date
        self.end_date = end_date
        self.count = count


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        begin_date = dateutil.parser.parse(dictionary.get('beginDate')).date() if dictionary.get('beginDate') else None
        end_date = dateutil.parser.parse(dictionary.get('endDate')).date() if dictionary.get('endDate') else None
        count = dictionary.get('count')

        # Return an object of this model
        return cls(begin_date,
                   end_date,
                   count)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class YieldmodifierEnum(object):

    """Implementation of the 'YieldmodifierEnum' enum.

    TODO: type enum description here.

    Attributes:
        INCREASE_PERCENT: TODO: type description here.
        DECREASE_PERCENT: TODO: type description here.
        INCREASE_AMOUNT: TODO: type description here.
        DECREASE_AMOUNT: TODO: type description here.

    """

    INCREASE_PERCENT = 'INCREASE_PERCENT'

    DECREASE_PERCENT = 'DECREASE_PERCENT'

    INCREASE_AMOUNT = 'INCREASE_AMOUNT'

    DECREASE_AMOUNT = 'DECREASE_AMOUNT'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class PushNotificationLinksModel(object):

    """Implementation of the 'PushNotificationLinksModel' model.

    Model for push notification links

    Attributes:
        book_link (string): Link for getting notifications about new
            reservations
        cancel_link (string): Link for getting notification about cancel
            reservation
        async_push (string): Link for push data for async messages
        request_to_book (string): Link for request to book for AirBnb

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "book_link":'bookLink',
        "cancel_link":'cancelLink',
        "async_push":'asyncPush',
        "request_to_book":'requestToBook'
    }

    def __init__(self,
                 book_link=None,
                 cancel_link=None,
                 async_push=None,
                 request_to_book=None):
        """Constructor for the PushNotificationLinksModel class"""

        # Initialize members of the class
        self.book_link = book_link
        self.cancel_link = cancel_link
        self.async_push = async_push
        self.request_to_book = request_to_book


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        book_link = dictionary.get('bookLink')
        cancel_link = dictionary.get('cancelLink')
        async_push = dictionary.get('asyncPush')
        request_to_book = dictionary.get('requestToBook')

        # Return an object of this model
        return cls(book_link,
                   cancel_link,
                   async_push,
                   request_to_book)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class SpaceUnitEnum(object):

    """Implementation of the 'SpaceUnitEnum' enum.

    TODO: type enum description here.

    Attributes:
        SQ_M: TODO: type description here.
        SQ_FT: TODO: type description here.

    """

    SQ_M = 'SQ_M'

    SQ_FT = 'SQ_FT'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.image

class ImageUrlList(object):

    """Implementation of the 'ImageUrlList' model.

    Model with list of URLs for one property

    Attributes:
        product_id (int): Id of the product
        images (list of Image): Images for property

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_id":'productId',
        "images":'images'
    }

    def __init__(self,
                 product_id=None,
                 images=None):
        """Constructor for the ImageUrlList class"""

        # Initialize members of the class
        self.product_id = product_id
        self.images = images


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        product_id = dictionary.get('productId')
        images = None
        if dictionary.get('images') != None:
            images = list()
            for structure in dictionary.get('images'):
                images.append(apimaticcalculatorlatest.models.image.Image.from_dictionary(structure))

        # Return an object of this model
        return cls(product_id,
                   images)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.rate
import apimaticcalculatorlatest.models.min_stay_model
import apimaticcalculatorlatest.models.max_stay_model
import apimaticcalculatorlatest.models.restriction
import apimaticcalculatorlatest.models.availability_model
import apimaticcalculatorlatest.models.available_count

class RatesAvailability(object):

    """Implementation of the 'RatesAvailability' model.

    Rates Availability model

    Attributes:
        product_id (int): ID of the product
        lead_time (int): Number of days before reservation in which
            reservation couldn’t be made. Allowed values are 0-7. If this
            value is set on property level - it will be used before than value
            on PM level.
        rates (list of Rate): List of models
        min_stays (list of MinStayModel): List of models
        max_stays (list of MaxStayModel): List of models
        restrictions (list of Restriction): List of models
        availabilities (list of AvailabilityModel): List of models
        available_count (list of AvailableCount): List of models (Only for MLT
            properties)

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_id":'productId',
        "lead_time":'leadTime',
        "rates":'rates',
        "min_stays":'minStays',
        "max_stays":'maxStays',
        "restrictions":'restrictions',
        "availabilities":'availabilities',
        "available_count":'availableCount'
    }

    def __init__(self,
                 product_id=None,
                 lead_time=None,
                 rates=None,
                 min_stays=None,
                 max_stays=None,
                 restrictions=None,
                 availabilities=None,
                 available_count=None):
        """Constructor for the RatesAvailability class"""

        # Initialize members of the class
        self.product_id = product_id
        self.lead_time = lead_time
        self.rates = rates
        self.min_stays = min_stays
        self.max_stays = max_stays
        self.restrictions = restrictions
        self.availabilities = availabilities
        self.available_count = available_count


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        product_id = dictionary.get('productId')
        lead_time = dictionary.get('leadTime')
        rates = None
        if dictionary.get('rates') != None:
            rates = list()
            for structure in dictionary.get('rates'):
                rates.append(apimaticcalculatorlatest.models.rate.Rate.from_dictionary(structure))
        min_stays = None
        if dictionary.get('minStays') != None:
            min_stays = list()
            for structure in dictionary.get('minStays'):
                min_stays.append(apimaticcalculatorlatest.models.min_stay_model.MinStayModel.from_dictionary(structure))
        max_stays = None
        if dictionary.get('maxStays') != None:
            max_stays = list()
            for structure in dictionary.get('maxStays'):
                max_stays.append(apimaticcalculatorlatest.models.max_stay_model.MaxStayModel.from_dictionary(structure))
        restrictions = None
        if dictionary.get('restrictions') != None:
            restrictions = list()
            for structure in dictionary.get('restrictions'):
                restrictions.append(apimaticcalculatorlatest.models.restriction.Restriction.from_dictionary(structure))
        availabilities = None
        if dictionary.get('availabilities') != None:
            availabilities = list()
            for structure in dictionary.get('availabilities'):
                availabilities.append(apimaticcalculatorlatest.models.availability_model.AvailabilityModel.from_dictionary(structure))
        available_count = None
        if dictionary.get('availableCount') != None:
            available_count = list()
            for structure in dictionary.get('availableCount'):
                available_count.append(apimaticcalculatorlatest.models.available_count.AvailableCount.from_dictionary(structure))

        # Return an object of this model
        return cls(product_id,
                   lead_time,
                   rates,
                   min_stays,
                   max_stays,
                   restrictions,
                   availabilities,
                   available_count)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class KindofInternetTypeEnum(object):

    """Implementation of the 'KindofInternetTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        WIFI: TODO: type description here.
        WIRED: TODO: type description here.

    """

    WIFI = 'WiFi'

    WIRED = 'Wired'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.push_notification_links_response import PushNotificationLinksResponse

class PushNotificationController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def get_notification_links(self):
        """Does a GET request to /info.

        This will return all notification URLs which are set. It will work on
        PMS level, so use PMS credentials.

        Returns:
            PushNotificationLinksResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/info'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, PushNotificationLinksResponse.from_dictionary)

    def create_push_notification_links(self,
                                       content_type,
                                       body):
        """Does a POST request to /info.

        Provide the links on which the requests about new reservation and
        cancel reservation will be sent. Links should be https.
        These links should be set on PMS level, so please use your PMS
        credentials. 

        Args:
            content_type (string): TODO: type description here. Example: 
            body (PushNotificationLinksRequest): TODO: type description here.
                Example: 

        Returns:
            PushNotificationLinksResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/info'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, PushNotificationLinksResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ManualPolicyTypeEnum(object):

    """Implementation of the 'ManualPolicyTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        PERCENTAGE: TODO: type description here.
        FLAT: TODO: type description here.

    """

    PERCENTAGE = 'PERCENTAGE'

    FLAT = 'FLAT'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class MessageModel(object):

    """Implementation of the 'MessageModel' model.

    Model for one message

    Attributes:
        message (string): Message text
        created_at (string): Time when message created
        user (UserEnum): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "message":'message',
        "created_at":'createdAt',
        "user":'user'
    }

    def __init__(self,
                 message=None,
                 created_at=None,
                 user=None):
        """Constructor for the MessageModel class"""

        # Initialize members of the class
        self.message = message
        self.created_at = created_at
        self.user = user


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        message = dictionary.get('message')
        created_at = dictionary.get('createdAt')
        user = dictionary.get('user')

        # Return an object of this model
        return cls(message,
                   created_at,
                   user)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DepositTypeEnum(object):

    """Implementation of the 'DepositTypeEnum' enum.

    First payment deposit type.

    Attributes:
        PERCENTAGE: TODO: type description here.
        FLAT: TODO: type description here.
        NON: TODO: type description here.

    """

    PERCENTAGE = 'PERCENTAGE'

    FLAT = 'FLAT'

    NON = 'NON'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser

class Thread(object):

    """Implementation of the 'Thread' model.

    TODO: type model description here.

    Attributes:
        id (int): Thread ID
        last_message_sent_at (string): Time when last message was sent
        last_message_text (string): Last message text
        channel_name (string): Channel from where come reservation
        channel_abb (ChannelABBEnum): TODO: type description here.
        guest_name (string): Name of guest
        guest_email_address (string): Email of guest
        product_id (int): ID of product in BookingPal database
        reservation_id (int): ID of reservation
        date_from (date): Start date of reservation. Date is in format
            "yyyy-MM-dd"
        date_to (date): End date of reservation. Date is in format
            "yyyy-MM-dd"

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "last_message_sent_at":'lastMessageSentAt',
        "last_message_text":'lastMessageText',
        "channel_name":'channelName',
        "channel_abb":'channelABB',
        "guest_name":'guestName',
        "guest_email_address":'guestEmailAddress',
        "product_id":'productId',
        "date_from":'dateFrom',
        "date_to":'dateTo',
        "reservation_id":'reservationId'
    }

    def __init__(self,
                 id=None,
                 last_message_sent_at=None,
                 last_message_text=None,
                 channel_name=None,
                 channel_abb=None,
                 guest_name=None,
                 guest_email_address=None,
                 product_id=None,
                 date_from=None,
                 date_to=None,
                 reservation_id=None):
        """Constructor for the Thread class"""

        # Initialize members of the class
        self.id = id
        self.last_message_sent_at = last_message_sent_at
        self.last_message_text = last_message_text
        self.channel_name = channel_name
        self.channel_abb = channel_abb
        self.guest_name = guest_name
        self.guest_email_address = guest_email_address
        self.product_id = product_id
        self.reservation_id = reservation_id
        self.date_from = date_from
        self.date_to = date_to


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        last_message_sent_at = dictionary.get('lastMessageSentAt')
        last_message_text = dictionary.get('lastMessageText')
        channel_name = dictionary.get('channelName')
        channel_abb = dictionary.get('channelABB')
        guest_name = dictionary.get('guestName')
        guest_email_address = dictionary.get('guestEmailAddress')
        product_id = dictionary.get('productId')
        date_from = dateutil.parser.parse(dictionary.get('dateFrom')).date() if dictionary.get('dateFrom') else None
        date_to = dateutil.parser.parse(dictionary.get('dateTo')).date() if dictionary.get('dateTo') else None
        reservation_id = dictionary.get('reservationId')

        # Return an object of this model
        return cls(id,
                   last_message_sent_at,
                   last_message_text,
                   channel_name,
                   channel_abb,
                   guest_name,
                   guest_email_address,
                   product_id,
                   date_from,
                   date_to,
                   reservation_id)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CompanyAddress(object):

    """Implementation of the 'CompanyAddress' model.

    TODO: type model description here.

    Attributes:
        country (string): Country of PM. Require 2 letter ISO code
        state (string): State (Region) of PM. Required for US properties.
        street_address (string): Street address of PM.
        city (string): City of PM
        zip (string): Zip code (postal code) of PM.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "country":'country',
        "state":'state',
        "street_address":'streetAddress',
        "city":'city',
        "zip":'zip'
    }

    def __init__(self,
                 country=None,
                 state=None,
                 street_address=None,
                 city=None,
                 zip=None):
        """Constructor for the CompanyAddress class"""

        # Initialize members of the class
        self.country = country
        self.state = state
        self.street_address = street_address
        self.city = city
        self.zip = zip


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        country = dictionary.get('country')
        state = dictionary.get('state')
        street_address = dictionary.get('streetAddress')
        city = dictionary.get('city')
        zip = dictionary.get('zip')

        # Return an object of this model
        return cls(country,
                   state,
                   street_address,
                   city,
                   zip)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class FeeTaxMandatory(object):

    """Implementation of the 'FeeTaxMandatory' model.

    TODO: type model description here.

    Attributes:
        is_fee_mandatory (bool): Used in BookingPal validator. Info does
            property require any fee or not. Default value is TRUE. This setup
            can be overridden on property level with different API call, which
            is stronger.
        is_tax_mandatory (bool): Used in BookingPal validator. Info does
            property require any tax or not. Default value is TRUE. This setup
            can be overridden on property level with different API call, which
            is stronger.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "is_fee_mandatory":'isFeeMandatory',
        "is_tax_mandatory":'isTaxMandatory'
    }

    def __init__(self,
                 is_fee_mandatory=None,
                 is_tax_mandatory=None):
        """Constructor for the FeeTaxMandatory class"""

        # Initialize members of the class
        self.is_fee_mandatory = is_fee_mandatory
        self.is_tax_mandatory = is_tax_mandatory


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        is_fee_mandatory = dictionary.get('isFeeMandatory')
        is_tax_mandatory = dictionary.get('isTaxMandatory')

        # Return an object of this model
        return cls(is_fee_mandatory,
                   is_tax_mandatory)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class AsynchronousValidationmodel(object):

    """Implementation of the 'AsynchronousValidationmodel' model.

    Model for Validation messages

    Attributes:
        product_id (int): Id of product in BookingPal
        validation_errors (string): Error message - explanation what are
            problems if validation failed.
        valid (bool): Is product valid

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_id":'productId',
        "valid":'valid',
        "validation_errors":'validationErrors'
    }

    def __init__(self,
                 product_id=None,
                 valid=None,
                 validation_errors=None):
        """Constructor for the AsynchronousValidationmodel class"""

        # Initialize members of the class
        self.product_id = product_id
        self.validation_errors = validation_errors
        self.valid = valid


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        product_id = dictionary.get('productId')
        valid = dictionary.get('valid')
        validation_errors = dictionary.get('validationErrors')

        # Return an object of this model
        return cls(product_id,
                   valid,
                   validation_errors)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class FeeTaxMandatorySetting(object):

    """Implementation of the 'FeeTaxMandatorySetting' model.

    TODO: type model description here.

    Attributes:
        product_id (int): Product id
        is_fee_mandatory (bool): Fee is mandatory
        is_tax_mandatory (bool): Tax is mandatory

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_id":'productId',
        "is_fee_mandatory":'isFeeMandatory',
        "is_tax_mandatory":'isTaxMandatory'
    }

    def __init__(self,
                 product_id=None,
                 is_fee_mandatory=None,
                 is_tax_mandatory=None):
        """Constructor for the FeeTaxMandatorySetting class"""

        # Initialize members of the class
        self.product_id = product_id
        self.is_fee_mandatory = is_fee_mandatory
        self.is_tax_mandatory = is_tax_mandatory


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        product_id = dictionary.get('productId')
        is_fee_mandatory = dictionary.get('isFeeMandatory')
        is_tax_mandatory = dictionary.get('isTaxMandatory')

        # Return an object of this model
        return cls(product_id,
                   is_fee_mandatory,
                   is_tax_mandatory)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.models.authorization import Authorization

class AuthorizationController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def get_login(self,
                  username,
                  password):
        """Does a GET request to /authc/login.

        In order to begin utilizing the platform APIs, your application must
        be authenticated and authorized to access domain resources. Follow the
        URL with your credentials and obtain an authorization token which is
        used in every request.
        You will have 2 types of tokens. One is on the PMS level, and this one
        should be used when you send requests related to PMS/PM data. For
        managing properties, you will need a token on PM level, with PM
        credentials. For every API call it will be noted which API credentials
        you should use.

        Args:
            username (string): Your account email address (for PMS or PM)
            password (string): Your password

        Returns:
            Authorization: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/authc/login'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'username': username,
            'password': password
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, Authorization.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.internet_policy
import apimaticcalculatorlatest.models.parking_policy
import apimaticcalculatorlatest.models.pet_policy

class Policy(object):

    """Implementation of the 'Policy' model.

    TODO: type model description here.

    Attributes:
        internet_policy (InternetPolicy): TODO: type description here.
        parking_policy (ParkingPolicy): TODO: type description here.
        pet_policy (PetPolicy): TODO: type description here.
        children_allowed (bool): Children policy
        smoking_allowed (bool): Smoking policy

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "children_allowed":'childrenAllowed',
        "smoking_allowed":'smokingAllowed',
        "internet_policy":'internetPolicy',
        "parking_policy":'parkingPolicy',
        "pet_policy":'petPolicy'
    }

    def __init__(self,
                 children_allowed=None,
                 smoking_allowed=None,
                 internet_policy=None,
                 parking_policy=None,
                 pet_policy=None):
        """Constructor for the Policy class"""

        # Initialize members of the class
        self.internet_policy = internet_policy
        self.parking_policy = parking_policy
        self.pet_policy = pet_policy
        self.children_allowed = children_allowed
        self.smoking_allowed = smoking_allowed


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        children_allowed = dictionary.get('childrenAllowed')
        smoking_allowed = dictionary.get('smokingAllowed')
        internet_policy = apimaticcalculatorlatest.models.internet_policy.InternetPolicy.from_dictionary(dictionary.get('internetPolicy')) if dictionary.get('internetPolicy') else None
        parking_policy = apimaticcalculatorlatest.models.parking_policy.ParkingPolicy.from_dictionary(dictionary.get('parkingPolicy')) if dictionary.get('parkingPolicy') else None
        pet_policy = apimaticcalculatorlatest.models.pet_policy.PetPolicy.from_dictionary(dictionary.get('petPolicy')) if dictionary.get('petPolicy') else None

        # Return an object of this model
        return cls(children_allowed,
                   smoking_allowed,
                   internet_policy,
                   parking_policy,
                   pet_policy)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class PaymentGatewaysTypeEnum(object):

    """Implementation of the 'PaymentGatewaysTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        PAYPAL: TODO: type description here.
        AUTHORIZE_NET: TODO: type description here.
        BRIDGE_PAY: TODO: type description here.
        PAY_BOX: TODO: type description here.
        DIBS: TODO: type description here.
        O_GONE: TODO: type description here.
        DOC_DATA: TODO: type description here.
        PAY_GATE: TODO: type description here.

    """

    PAYPAL = 'PAYPAL'

    AUTHORIZE_NET = 'AUTHORIZE_NET'

    BRIDGE_PAY = 'BRIDGE_PAY'

    PAY_BOX = 'PAY_BOX'

    DIBS = 'DIBS'

    O_GONE = 'O_GONE'

    DOC_DATA = 'DOC_DATA'

    PAY_GATE = 'PAY_GATE'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class FunctionsRequestToBook(object):

    """Implementation of the 'FunctionsRequestToBook' model.

    Request to book answer model

    Attributes:
        request_to_book_type (RequestToBookTypeEnum): TODO: type description
            here.
        request_to_book_decline_reason_type
            (RequestToBookDeclineReasonTypeEnum): TODO: type description
            here.
        decline_message_to_guest (string): Message to guest
        reservation_id (int): Reservation for request to book

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "request_to_book_type":'requestToBookType',
        "reservation_id":'reservationId',
        "request_to_book_decline_reason_type":'requestToBookDeclineReasonType',
        "decline_message_to_guest":'declineMessageToGuest'
    }

    def __init__(self,
                 request_to_book_type=None,
                 reservation_id=None,
                 request_to_book_decline_reason_type=None,
                 decline_message_to_guest=None):
        """Constructor for the FunctionsRequestToBook class"""

        # Initialize members of the class
        self.request_to_book_type = request_to_book_type
        self.request_to_book_decline_reason_type = request_to_book_decline_reason_type
        self.decline_message_to_guest = decline_message_to_guest
        self.reservation_id = reservation_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        request_to_book_type = dictionary.get('requestToBookType')
        reservation_id = dictionary.get('reservationId')
        request_to_book_decline_reason_type = dictionary.get('requestToBookDeclineReasonType')
        decline_message_to_guest = dictionary.get('declineMessageToGuest')

        # Return an object of this model
        return cls(request_to_book_type,
                   reservation_id,
                   request_to_book_decline_reason_type,
                   decline_message_to_guest)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.payment_gateways

class CreditCard(object):

    """Implementation of the 'CreditCard' model.

    TODO: type model description here.

    Attributes:
        credit_card_type (CreditCardTypeEnum): TODO: type description here.
        payment_gateways (PaymentGateways): TODO: type description here.
        credit_card_list (list of CreditCardListEnum): List of acceptable
            credit cards. Allowed only if type is TRANSMIT.
            {MASTER_CARD,VISA,AMERICAN_EXPRESS,DINERS_CLUB,DISCOVER}. If POST
            method selected it will select all creditCardList.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "credit_card_type":'creditCardType',
        "payment_gateways":'paymentGateways',
        "credit_card_list":'creditCardList'
    }

    def __init__(self,
                 credit_card_type=None,
                 payment_gateways=None,
                 credit_card_list=None):
        """Constructor for the CreditCard class"""

        # Initialize members of the class
        self.credit_card_type = credit_card_type
        self.payment_gateways = payment_gateways
        self.credit_card_list = credit_card_list


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        credit_card_type = dictionary.get('creditCardType')
        payment_gateways = apimaticcalculatorlatest.models.payment_gateways.PaymentGateways.from_dictionary(dictionary.get('paymentGateways')) if dictionary.get('paymentGateways') else None
        credit_card_list = dictionary.get('creditCardList')

        # Return an object of this model
        return cls(credit_card_type,
                   payment_gateways,
                   credit_card_list)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.getmessagethreads_response import GetmessagethreadsResponse
from apimaticcalculatorlatest.models.api_responsewithout_data import APIResponsewithoutData
from apimaticcalculatorlatest.models.getmessagelistforspecificthread_response import GetmessagelistforspecificthreadResponse

class MessagingController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def getmessagethreads(self,
                          page,
                          limit,
                          thread_type):
        """Does a GET request to /message/allthreads/{threadType}.

        This function allows the logged in user to get all message threads or
        message threads with unresponded message from guest for whole PM. You
        need to use PM credentials. There is also paging as optional values.
        If you do not pass this value, we will return first page and 10
        threads per page. And in heading you will get a link for the next
        page.

        Args:
            page (int): Number of current page
            limit (int): Limit of how many threads will be showed at one page
            thread_type (string): Request all threads or only threads with 
                unanswered message {new,all}

        Returns:
            GetmessagethreadsResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/message/allthreads/{threadType}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'threadType': thread_type
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'page': page,
            'limit': limit
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetmessagethreadsResponse.from_dictionary)

    def postnewmessageforspecificthread(self,
                                        content_type,
                                        body):
        """Does a POST request to /message.

        This function will allow PM to post new messages in already existing
        threads.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (PostnewmessageforspecificthreadRequest): TODO: type
                description here. Example: 

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/message'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def getmessagelistforspecificthread(self,
                                        thread_id):
        """Does a GET request to /message/specificthread/{threadId}/.

        This function allows the logged in user to get a list of all messages
        from passed thread Id. You need to use PM credentials.

        Args:
            thread_id (string): ID of the thread

        Returns:
            GetmessagelistforspecificthreadResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/message/specificthread/{threadId}/'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'threadId': thread_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetmessagelistforspecificthreadResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ParkingPolicy(object):

    """Implementation of the 'ParkingPolicy' model.

    TODO: type model description here.

    Attributes:
        access_parking (bool): Access parking into properties {true,false}
        located_parking (LocatedParkingTypeEnum): TODO: type description
            here.
        private_parking (bool): Parking is private or no. {true,false}
        charge_parking (string): Charge parking. Example: “Free”, “$ 100”.
        time_cost_parking (TimeCostParkingEnum): TODO: type description here.
        necessary_reservation_parking (ReservationParkingTypeEnum): TODO: type
            description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "access_parking":'accessParking',
        "located_parking":'locatedParking',
        "private_parking":'privateParking',
        "charge_parking":'chargeParking',
        "time_cost_parking":'timeCostParking',
        "necessary_reservation_parking":'necessaryReservationParking'
    }

    def __init__(self,
                 access_parking=None,
                 located_parking=None,
                 private_parking=None,
                 charge_parking=None,
                 time_cost_parking=None,
                 necessary_reservation_parking=None):
        """Constructor for the ParkingPolicy class"""

        # Initialize members of the class
        self.access_parking = access_parking
        self.located_parking = located_parking
        self.private_parking = private_parking
        self.charge_parking = charge_parking
        self.time_cost_parking = time_cost_parking
        self.necessary_reservation_parking = necessary_reservation_parking


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        access_parking = dictionary.get('accessParking')
        located_parking = dictionary.get('locatedParking')
        private_parking = dictionary.get('privateParking')
        charge_parking = dictionary.get('chargeParking')
        time_cost_parking = dictionary.get('timeCostParking')
        necessary_reservation_parking = dictionary.get('necessaryReservationParking')

        # Return an object of this model
        return cls(access_parking,
                   located_parking,
                   private_parking,
                   charge_parking,
                   time_cost_parking,
                   necessary_reservation_parking)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class LocatedParkingTypeEnum(object):

    """Implementation of the 'LocatedParkingTypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        ONSITE: TODO: type description here.
        NEARBY: TODO: type description here.

    """

    ONSITE = 'OnSite'

    NEARBY = 'Nearby'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class InternetPolicy(object):

    """Implementation of the 'InternetPolicy' model.

    TODO: type model description here.

    Attributes:
        access_internet (bool): Access internet into properties
        kind_of_internet (KindofInternetTypeEnum): TODO: type description
            here.
        available_internet (AvailableInternetEnum): TODO: type description
            here.
        charge_internet (string): Charge internet. Example: “Free”, “$ 100”.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "access_internet":'accessInternet',
        "kind_of_internet":'kindOfInternet',
        "available_internet":'availableInternet',
        "charge_internet":'chargeInternet'
    }

    def __init__(self,
                 access_internet=None,
                 kind_of_internet=None,
                 available_internet=None,
                 charge_internet=None):
        """Constructor for the InternetPolicy class"""

        # Initialize members of the class
        self.access_internet = access_internet
        self.kind_of_internet = kind_of_internet
        self.available_internet = available_internet
        self.charge_internet = charge_internet


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        access_internet = dictionary.get('accessInternet')
        kind_of_internet = dictionary.get('kindOfInternet')
        available_internet = dictionary.get('availableInternet')
        charge_internet = dictionary.get('chargeInternet')

        # Return an object of this model
        return cls(access_internet,
                   kind_of_internet,
                   available_internet,
                   charge_internet)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class CreditCardListEnum(object):

    """Implementation of the 'CreditCardListEnum' enum.

    TODO: type enum description here.

    Attributes:
        MASTER_CARD: TODO: type description here.
        VISA: TODO: type description here.
        AMERICAN_EXPRESS: TODO: type description here.
        DINERS_CLUB: TODO: type description here.
        DISCOVER: TODO: type description here.

    """

    MASTER_CARD = 'MASTER_CARD'

    VISA = 'VISA'

    AMERICAN_EXPRESS = 'AMERICAN_EXPRESS'

    DINERS_CLUB = 'DINERS_CLUB'

    DISCOVER = 'DISCOVER'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class BedConfigurationEnum(object):

    """Implementation of the 'BedConfigurationEnum' enum.

    TODO: type enum description here.

    Attributes:
        RMA58: TODO: type description here.
        RMA86: TODO: type description here.
        RMA102: TODO: type description here.
        RMA113: TODO: type description here.
        RMA200: TODO: type description here.
        RMA201: TODO: type description here.
        RMA203: TODO: type description here.
        RMA6032: TODO: type description here.
        RMA33: TODO: type description here.
        RMA26: TODO: type description here.
        RMA6038: TODO: type description here.
        RMA6118: TODO: type description here.
        RMA6119: TODO: type description here.
        RMA6120: TODO: type description here.
        RMA6121: TODO: type description here.
        RMA6122: TODO: type description here.

    """

    RMA58 = 'RMA58'

    RMA86 = 'RMA86'

    RMA102 = 'RMA102'

    RMA113 = 'RMA113'

    RMA200 = 'RMA200'

    RMA201 = 'RMA201'

    RMA203 = 'RMA203'

    RMA6032 = 'RMA6032'

    RMA33 = 'RMA33'

    RMA26 = 'RMA26'

    RMA6038 = 'RMA6038'

    RMA6118 = 'RMA6118'

    RMA6119 = 'RMA6119'

    RMA6120 = 'RMA6120'

    RMA6121 = 'RMA6121'

    RMA6122 = 'RMA6122'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class UserEnum(object):

    """Implementation of the 'UserEnum' enum.

    TODO: type enum description here.

    Attributes:
        PROPERTY_MANAGER: TODO: type description here.
        GUEST: TODO: type description here.

    """

    PROPERTY_MANAGER = 'PROPERTY_MANAGER'

    GUEST = 'GUEST'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Authorization(object):

    """Implementation of the 'Authorization' model.

    Authorization (Login) response

    Attributes:
        token (string): Generated token for authorization. It must be used in
            every request to API as param jwt. Token is valid for 1h
        message (string): Message
        is_error (bool): Is request success or not
        error_message (list of string): Error Message(s) in Array format
        code (string): Response code
        organization_id (int): Organization id - PMS ID
        supplier_id (int): Supplier ID (Property Manager ID - or PMS ID -
            depend on account on which you are logged in)
        party_id (int): Deprecated field. It will be removed in version 3.3.
            Please use supplierId field instead
        name (string): Account name
        currency (string): Account currency

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "token":'token',
        "message":'message',
        "is_error":'is_error',
        "error_message":'errorMessage',
        "organization_id":'organizationId',
        "supplier_id":'supplierId',
        "party_id":'partyId',
        "name":'name',
        "currency":'currency',
        "code":'code'
    }

    def __init__(self,
                 token=None,
                 message=None,
                 is_error=None,
                 error_message=None,
                 organization_id=None,
                 supplier_id=None,
                 party_id=None,
                 name=None,
                 currency=None,
                 code=None):
        """Constructor for the Authorization class"""

        # Initialize members of the class
        self.token = token
        self.message = message
        self.is_error = is_error
        self.error_message = error_message
        self.code = code
        self.organization_id = organization_id
        self.supplier_id = supplier_id
        self.party_id = party_id
        self.name = name
        self.currency = currency


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        token = dictionary.get('token')
        message = dictionary.get('message')
        is_error = dictionary.get('is_error')
        error_message = dictionary.get('errorMessage')
        organization_id = dictionary.get('organizationId')
        supplier_id = dictionary.get('supplierId')
        party_id = dictionary.get('partyId')
        name = dictionary.get('name')
        currency = dictionary.get('currency')
        code = dictionary.get('code')

        # Return an object of this model
        return cls(token,
                   message,
                   is_error,
                   error_message,
                   organization_id,
                   supplier_id,
                   party_id,
                   name,
                   currency,
                   code)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.los_rate

class LosRatesProduct(object):

    """Implementation of the 'LosRatesProduct' model.

    Model for product LOS rates

    Attributes:
        product_id (int): ID of the product
        los_rates (list of LosRate): List of models. Max size array for
            LosRates object 1000

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_id":'productId',
        "los_rates":'losRates'
    }

    def __init__(self,
                 product_id=None,
                 los_rates=None):
        """Constructor for the LosRatesProduct class"""

        # Initialize members of the class
        self.product_id = product_id
        self.los_rates = los_rates


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        product_id = dictionary.get('productId')
        los_rates = None
        if dictionary.get('losRates') != None:
            los_rates = list()
            for structure in dictionary.get('losRates'):
                los_rates.append(apimaticcalculatorlatest.models.los_rate.LosRate.from_dictionary(structure))

        # Return an object of this model
        return cls(product_id,
                   los_rates)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class PropertyTypesEnum(object):

    """Implementation of the 'PropertyTypesEnum' enum.

    TODO: type enum description here.

    Attributes:
        PCT101: TODO: type description here.
        PCT102: TODO: type description here.
        PCT103: TODO: type description here.
        PCT104: TODO: type description here.
        PCT105: TODO: type description here.
        PCT106: TODO: type description here.
        PCT107: TODO: type description here.
        PCT108: TODO: type description here.
        PCT109: TODO: type description here.
        PCT110: TODO: type description here.
        PCT111: TODO: type description here.
        PCT112: TODO: type description here.
        PCT113: TODO: type description here.
        PCT114: TODO: type description here.
        PCT115: TODO: type description here.
        PCT116: TODO: type description here.
        PCT117: TODO: type description here.
        PCT118: TODO: type description here.
        PCT119: TODO: type description here.
        PCT12: TODO: type description here.
        PCT120: TODO: type description here.
        PCT121: TODO: type description here.
        PCT122: TODO: type description here.
        PCT123: TODO: type description here.
        PCT124: TODO: type description here.
        PCT125: TODO: type description here.
        PCT126: TODO: type description here.
        PCT127: TODO: type description here.
        PCT128: TODO: type description here.
        PCT14: TODO: type description here.
        PCT15: TODO: type description here.
        PCT16: TODO: type description here.
        PCT18: TODO: type description here.
        PCT19: TODO: type description here.
        PCT20: TODO: type description here.
        PCT21: TODO: type description here.
        PCT22: TODO: type description here.
        PCT23: TODO: type description here.
        PCT25: TODO: type description here.
        PCT26: TODO: type description here.
        PCT27: TODO: type description here.
        PCT28: TODO: type description here.
        PCT29: TODO: type description here.
        PCT3: TODO: type description here.
        PCT30: TODO: type description here.
        PCT31: TODO: type description here.
        PCT32: TODO: type description here.
        PCT33: TODO: type description here.
        PCT34: TODO: type description here.
        PCT35: TODO: type description here.
        PCT36: TODO: type description here.
        PCT37: TODO: type description here.
        PCT4: TODO: type description here.
        PCT40: TODO: type description here.
        PCT41: TODO: type description here.
        PCT44: TODO: type description here.
        PCT45: TODO: type description here.
        PCT46: TODO: type description here.
        PCT5: TODO: type description here.
        PCT50: TODO: type description here.
        PCT51: TODO: type description here.
        PCT52: TODO: type description here.
        PCT6: TODO: type description here.
        PCT7: TODO: type description here.
        PCT8: TODO: type description here.

    """

    PCT101 = 'PCT101'

    PCT102 = 'PCT102'

    PCT103 = 'PCT103'

    PCT104 = 'PCT104'

    PCT105 = 'PCT105'

    PCT106 = 'PCT106'

    PCT107 = 'PCT107'

    PCT108 = 'PCT108'

    PCT109 = 'PCT109'

    PCT110 = 'PCT110'

    PCT111 = 'PCT111'

    PCT112 = 'PCT112'

    PCT113 = 'PCT113'

    PCT114 = 'PCT114'

    PCT115 = 'PCT115'

    PCT116 = 'PCT116'

    PCT117 = 'PCT117'

    PCT118 = 'PCT118'

    PCT119 = 'PCT119'

    PCT12 = 'PCT12'

    PCT120 = 'PCT120'

    PCT121 = 'PCT121'

    PCT122 = 'PCT122'

    PCT123 = 'PCT123'

    PCT124 = 'PCT124'

    PCT125 = 'PCT125'

    PCT126 = 'PCT126'

    PCT127 = 'PCT127'

    PCT128 = 'PCT128'

    PCT14 = 'PCT14'

    PCT15 = 'PCT15'

    PCT16 = 'PCT16'

    PCT18 = 'PCT18'

    PCT19 = 'PCT19'

    PCT20 = 'PCT20'

    PCT21 = 'PCT21'

    PCT22 = 'PCT22'

    PCT23 = 'PCT23'

    PCT25 = 'PCT25'

    PCT26 = 'PCT26'

    PCT27 = 'PCT27'

    PCT28 = 'PCT28'

    PCT29 = 'PCT29'

    PCT3 = 'PCT3'

    PCT30 = 'PCT30'

    PCT31 = 'PCT31'

    PCT32 = 'PCT32'

    PCT33 = 'PCT33'

    PCT34 = 'PCT34'

    PCT35 = 'PCT35'

    PCT36 = 'PCT36'

    PCT37 = 'PCT37'

    PCT4 = 'PCT4'

    PCT40 = 'PCT40'

    PCT41 = 'PCT41'

    PCT44 = 'PCT44'

    PCT45 = 'PCT45'

    PCT46 = 'PCT46'

    PCT5 = 'PCT5'

    PCT50 = 'PCT50'

    PCT51 = 'PCT51'

    PCT52 = 'PCT52'

    PCT6 = 'PCT6'

    PCT7 = 'PCT7'

    PCT8 = 'PCT8'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser

class Fee(object):

    """Implementation of the 'Fee' model.

    TODO: type model description here.

    Attributes:
        begin_date (date): Fee applies from Date. Date should be in format
            "yyyy-MM-dd"
        end_date (date): Fee applies to Date. Date should be in format
            "yyyy-MM-dd"
        entity_type (FeeEntityTypeEnum): TODO: type description here.
        fee_type (FeeTypeEnum): TODO: type description here.
        option (int): Number of guests when set extra person fee. Only values
            >0 are allowed.
        name (string): Fee name.  For example: Extra person, Cleaning fee,
            Parking etc.
        tax_type (FeetaxTypeEnum): TODO: type description here.
        unit (FeeUnitEnum): TODO: type description here.
        value (float): Fee value
        value_type (FeeValueTypeEnum): Value Type {FLAT, PERCENT}
        alt_id (string): Alternative Id of the fee (fee id in your system)

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "entity_type":'entityType',
        "fee_type":'feeType',
        "name":'name',
        "unit":'unit',
        "value":'value',
        "value_type":'valueType',
        "begin_date":'beginDate',
        "end_date":'endDate',
        "option":'option',
        "tax_type":'taxType',
        "alt_id":'altId'
    }

    def __init__(self,
                 entity_type=None,
                 fee_type=None,
                 name=None,
                 unit=None,
                 value=None,
                 value_type=None,
                 begin_date=None,
                 end_date=None,
                 option=None,
                 tax_type=None,
                 alt_id=None):
        """Constructor for the Fee class"""

        # Initialize members of the class
        self.begin_date = begin_date
        self.end_date = end_date
        self.entity_type = entity_type
        self.fee_type = fee_type
        self.option = option
        self.name = name
        self.tax_type = tax_type
        self.unit = unit
        self.value = value
        self.value_type = value_type
        self.alt_id = alt_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        entity_type = dictionary.get('entityType')
        fee_type = dictionary.get('feeType')
        name = dictionary.get('name')
        unit = dictionary.get('unit')
        value = dictionary.get('value')
        value_type = dictionary.get('valueType')
        begin_date = dateutil.parser.parse(dictionary.get('beginDate')).date() if dictionary.get('beginDate') else None
        end_date = dateutil.parser.parse(dictionary.get('endDate')).date() if dictionary.get('endDate') else None
        option = dictionary.get('option')
        tax_type = dictionary.get('taxType')
        alt_id = dictionary.get('altId')

        # Return an object of this model
        return cls(entity_type,
                   fee_type,
                   name,
                   unit,
                   value,
                   value_type,
                   begin_date,
                   end_date,
                   option,
                   tax_type,
                   alt_id)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.company_address
import apimaticcalculatorlatest.models.phone

class CompanyDetails(object):

    """Implementation of the 'CompanyDetails' model.

    TODO: type model description here.

    Attributes:
        account_id (string): Unique ID of PM in PMS
        company_name (string): Name of PM
        language (string): Language 2 letter value  as ISO 639-1 code
        full_name (string): First and Last Name
        company_address (CompanyAddress): TODO: type description here.
        website (string): Company (PM) website URL
        email (string): Email of PM. Email need to be unique in BP system, so
            you might receive error if we already have this email in our
            system
        phone (Phone): TODO: type description here.
        password (string): Password for accessing PM. If the password is not
            passed in the request random password will be generated and
            returned in response. Password will be in response only on create
            and if it is manually generated. Special characters are not
            allowed, instead use UTF-8 codes, for example instead of # use
            %23
        currency (string): PM default currency. ISO 4217 code is required

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "account_id":'accountId',
        "company_name":'companyName',
        "language":'language',
        "full_name":'fullName',
        "company_address":'companyAddress',
        "website":'website',
        "email":'email',
        "phone":'phone',
        "currency":'currency',
        "password":'password'
    }

    def __init__(self,
                 account_id=None,
                 company_name=None,
                 language=None,
                 full_name=None,
                 company_address=None,
                 website=None,
                 email=None,
                 phone=None,
                 currency=None,
                 password=None):
        """Constructor for the CompanyDetails class"""

        # Initialize members of the class
        self.account_id = account_id
        self.company_name = company_name
        self.language = language
        self.full_name = full_name
        self.company_address = company_address
        self.website = website
        self.email = email
        self.phone = phone
        self.password = password
        self.currency = currency


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        account_id = dictionary.get('accountId')
        company_name = dictionary.get('companyName')
        language = dictionary.get('language')
        full_name = dictionary.get('fullName')
        company_address = apimaticcalculatorlatest.models.company_address.CompanyAddress.from_dictionary(dictionary.get('companyAddress')) if dictionary.get('companyAddress') else None
        website = dictionary.get('website')
        email = dictionary.get('email')
        phone = apimaticcalculatorlatest.models.phone.Phone.from_dictionary(dictionary.get('phone')) if dictionary.get('phone') else None
        currency = dictionary.get('currency')
        password = dictionary.get('password')

        # Return an object of this model
        return cls(account_id,
                   company_name,
                   language,
                   full_name,
                   company_address,
                   website,
                   email,
                   phone,
                   currency,
                   password)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser

class CancelReservationnotificationobject(object):

    """Implementation of the 'CancelReservationnotificationobject' model.

    TODO: type model description here.

    Attributes:
        reservation_id (string): Id of the reservation in BookingPal
        product_id (string): Id of the product in BookingPal
        supplier_id (int): Id of the property manager
        agent_name (string): Agent name/Channel name
        confirmation_id (string): Channel confirmation code
        unique_key (string): Unique code to identify that the request is from
            BookingPal. This value is unique for every PMS (and it will be
            different in different environments).
        new_state (string): It will always be "Cancelled" in this request
        customer_name (string): Guest full name (in format firstName,
            lastName)
        from_date (date): Reservation date from. Date is in format
            "yyyy-MM-dd"
        to_date (date): Reservation date to. Date is in format "yyyy-MM-dd"
        adult (int): Number of adults
        child (int): Number of children
        email (string): Guest email
        phone (string): Guest phone
        notes (string): Guest notes
        credit_card_type (string): Credit card type
        total (float): Best available rate (This is the total value that
            guests will pay, including rate, fees, taxes, and all commissions.
            )

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "reservation_id":'reservationId',
        "product_id":'productId',
        "supplier_id":'supplierId',
        "agent_name":'agentName',
        "confirmation_id":'confirmationId',
        "unique_key":'uniqueKey',
        "new_state":'newState',
        "customer_name":'customerName',
        "from_date":'fromDate',
        "to_date":'toDate',
        "adult":'adult',
        "child":'child',
        "email":'email',
        "total":'total',
        "phone":'phone',
        "notes":'notes',
        "credit_card_type":'creditCardType'
    }

    def __init__(self,
                 reservation_id=None,
                 product_id=None,
                 supplier_id=None,
                 agent_name=None,
                 confirmation_id=None,
                 unique_key=None,
                 new_state=None,
                 customer_name=None,
                 from_date=None,
                 to_date=None,
                 adult=None,
                 child=None,
                 email=None,
                 total=None,
                 phone=None,
                 notes=None,
                 credit_card_type=None):
        """Constructor for the CancelReservationnotificationobject class"""

        # Initialize members of the class
        self.reservation_id = reservation_id
        self.product_id = product_id
        self.supplier_id = supplier_id
        self.agent_name = agent_name
        self.confirmation_id = confirmation_id
        self.unique_key = unique_key
        self.new_state = new_state
        self.customer_name = customer_name
        self.from_date = from_date
        self.to_date = to_date
        self.adult = adult
        self.child = child
        self.email = email
        self.phone = phone
        self.notes = notes
        self.credit_card_type = credit_card_type
        self.total = total


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        reservation_id = dictionary.get('reservationId')
        product_id = dictionary.get('productId')
        supplier_id = dictionary.get('supplierId')
        agent_name = dictionary.get('agentName')
        confirmation_id = dictionary.get('confirmationId')
        unique_key = dictionary.get('uniqueKey')
        new_state = dictionary.get('newState')
        customer_name = dictionary.get('customerName')
        from_date = dateutil.parser.parse(dictionary.get('fromDate')).date() if dictionary.get('fromDate') else None
        to_date = dateutil.parser.parse(dictionary.get('toDate')).date() if dictionary.get('toDate') else None
        adult = dictionary.get('adult')
        child = dictionary.get('child')
        email = dictionary.get('email')
        total = dictionary.get('total')
        phone = dictionary.get('phone')
        notes = dictionary.get('notes')
        credit_card_type = dictionary.get('creditCardType')

        # Return an object of this model
        return cls(reservation_id,
                   product_id,
                   supplier_id,
                   agent_name,
                   confirmation_id,
                   unique_key,
                   new_state,
                   customer_name,
                   from_date,
                   to_date,
                   adult,
                   child,
                   email,
                   total,
                   phone,
                   notes,
                   credit_card_type)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AvailableInternetEnum(object):

    """Implementation of the 'AvailableInternetEnum' enum.

    TODO: type enum description here.

    Attributes:
        ALLAREAS: TODO: type description here.
        BUSINESSCENTER: TODO: type description here.
        SOMEROOMS: TODO: type description here.

    """

    ALLAREAS = 'AllAreas'

    BUSINESSCENTER = 'BusinessCenter'

    SOMEROOMS = 'SomeRooms'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AsynchronouspushmessagetypeEnum(object):

    """Implementation of the 'AsynchronouspushmessagetypeEnum' enum.

    TODO: type enum description here.

    Attributes:
        BP_VALIDATION: TODO: type description here.

    """

    BP_VALIDATION = 'BP_VALIDATION'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class MessageRequestFromSupplier(object):

    """Implementation of the 'MessageRequestFromSupplier' model.

    TODO: type model description here.

    Attributes:
        thread_id (int): ID of thread
        message (string): Message text

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "thread_id":'threadId',
        "message":'message'
    }

    def __init__(self,
                 thread_id=None,
                 message=None):
        """Constructor for the MessageRequestFromSupplier class"""

        # Initialize members of the class
        self.thread_id = thread_id
        self.message = message


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        thread_id = dictionary.get('threadId')
        message = dictionary.get('message')

        # Return an object of this model
        return cls(thread_id,
                   message)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.yieldresponse import Yieldresponse

class YieldsController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def get_ym_rlistbyproduct_id(self,
                                 product_id):
        """Does a GET request to /yield/{productId}.

        This function allows the logged in user to get yield management rules
        list of the specific product.

        Args:
            product_id (string): ID of the property

        Returns:
            Yieldresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/yield/{productId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'productId': product_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, Yieldresponse.from_dictionary)

    def create_ymr(self,
                   content_type,
                   body):
        """Does a POST request to /yield.

        This function allows the logged-in user to add yield management rules
        for the specific product. Yield management rules can affect the final
        price of the property depending on some special conditions (like the
        length of stay, early booking, etc.). These rules automate price
        manipulations, on an inquiry by inquiry basis. When set criteria are
        met, they help maximize revenue and occupancy.
        How is the price calculated?
        The price for a night is calculated based on the basic price and the
        yield management rules.
        - If no YMR:
        {basic price per night} = price per night
        - If YMR is set it can Increase/decrease percent or increase/decrease
        amount:
        	{basic price per night} + {yield amount} = {price per night}
        	or
        	{basic price per night} - {yield amount} = {price per night}
        The below examples will use the scenario to walk you step by step and
        explain how the price is calculated based on different YMRs. 
        Let’s say that the basic price per night for 2016 is 100 USD.
        This function is used also for updating yield. So if you already
        create a specific yield for some date - and you send a new one - we
        will update the yield for this date.
        If you need to delete a specific yield type - you can send an empty
        list for that type.
        Important: The maximum allowed end date is 3 years in the future.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (CreateYieldRequest): TODO: type description here. Example: 

        Returns:
            Yieldresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/yield'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, Yieldresponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.fee_tax_validation_setting_response import FeeTaxValidationSettingResponse
from apimaticcalculatorlatest.models.api_responsewithout_data import APIResponsewithoutData

class FeeAndTaxMandatoryAtThePropertyLevelController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def getfeeandtaxmandatory(self):
        """Does a GET request to /validation-settings/get-validation.

        This function allows the logged in user to get info about current set
        for all PM properties are fees/taxes set to be mandatory or not.

        Returns:
            FeeTaxValidationSettingResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/validation-settings/get-validation'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, FeeTaxValidationSettingResponse.from_dictionary)

    def create_importorupdatefeeandtaxmandatory(self,
                                                content_type,
                                                body):
        """Does a POST request to /validation-settings/import-update.

        This function allows the logged in user to import or update a fee and
        tax mandatory.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (SetfeeandtaxvalidationsettingRequest): TODO: type
                description here. Example: 

        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/validation-settings/import-update'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)

    def create_remove_validation_settings(self,
                                          content_type,
                                          body):
        """Does a POST request to /validation-settings/removed.

        This function allows the logged in user to remove any setup on
        property level and to return on default (which is that fee/taxes are
        mandatory). This API call will accept a list of properties.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (PropertyListRequest): TODO: type description here. Example:
                
        Returns:
            APIResponsewithoutData: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/validation-settings/removed'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, APIResponsewithoutData.from_dictionary)



# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import dateutil.parser
import apimaticcalculatorlatest.models.notes
import apimaticcalculatorlatest.models.attributes_with_quantity
import apimaticcalculatorlatest.models.nearby_amenity
import apimaticcalculatorlatest.models.bedroom_configuration
import apimaticcalculatorlatest.models.policy
import apimaticcalculatorlatest.models.location

class Property(object):

    """Implementation of the 'Property' model.

    TODO: type model description here.

    Attributes:
        name (string): Name of the property to display in the list
        id (int): Property ID in BookingPal
        alt_id (int): Alternative Id of the property (ID in your PMS system). 
            Note: this field you can not update, so this field will not be
            used during update.
        supplier_id (int): Id of the Property Manager (not be used for
            creating new property. Property will have ID of current authorized
            user)
        rooms (int): Number of bedrooms. Number of bedrooms should be > 0.
            Value 0 is only allowed in case property type  is Studio (PCT46 or
            PCT110)
        bathrooms (int): Number of bathrooms
        toilets (int): Number of toilets
        total_beds (int): Property’s total number of beds
        space (float): Property size
        space_unit (SpaceUnitEnum): TODO: type description here.
        persons (int): Maximum number of allowed adults
        childs (int): Number of allowed children (from 7 to 12 years)
        latitude (float): Latitude of the property (Must set field latitude
            and longitude or location)
        longitude (float): Longitude of the property (Must set field latitude
            and longitude or location)
        living_room (int): Number of Living rooms
        notes (Notes): Model where you can define different kinds of text
            values. If you need to delete some kind of texts, for example
            short description, you can do this on Update call (PUT), and you
            need to pass empty array for texts value, for example : 
            "shortDescription": {  "texts": [  ] }
        attributes_with_quantity (list of AttributesWithQuantity): Use this
            param instead of previous if you need to set quantity more than 1
            of attributes. If use both in POST request this will overwrite the
            previous list (under param attributes).
        nearby_amenities (list of NearbyAmenity): List of Nearby Attributes
            models. Check allowed values in Appendix.
        property_type (PropertyTypesEnum): TODO: type description here.
        bedroom_configuration (BedroomConfiguration): TODO: type description
            here.
        check_in_time (string): Time of Check in (HH:MM:SS)
        check_in_to_time (string): Time Check in to (HH:MM:SS)
        check_out_time (string): Time of Check out (HH:MM:SS)
        currency (string): Property currency. ISO 4217 code is required.
        policy (Policy): TODO: type description here.
        location (Location): TODO: type description here.
        supported_los_rates (bool): If true - means that the property supports
            only LOS rates. So daily rates can not be sent and updated.
            Default is false.
        tax_number (string): Tax number for product
        tourist_license_number (string): Tourist license number
        tourist_license_expiry_date (date): Tourist license expiry date.
            Correct date format is YYYY-MM-DD.
        multi_unit (MultiUnitEnum): Enum for product multyunit type.
        parent_id (int): This fields should not be used unless your property
            is not MLT (check field multiunit). In this case you must set
            owner (parent) id property to which this property will belong.
            Also you can not update this property.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "rooms":'rooms',
        "bathrooms":'bathrooms',
        "persons":'persons',
        "property_type":'propertyType',
        "currency":'currency',
        "supported_los_rates":'supportedLosRates',
        "id":'id',
        "alt_id":'altId',
        "supplier_id":'supplierId',
        "toilets":'toilets',
        "total_beds":'totalBeds',
        "space":'space',
        "space_unit":'spaceUnit',
        "childs":'childs',
        "latitude":'latitude',
        "longitude":'longitude',
        "living_room":'livingRoom',
        "notes":'notes',
        "attributes_with_quantity":'attributesWithQuantity',
        "nearby_amenities":'nearbyAmenities',
        "bedroom_configuration":'bedroomConfiguration',
        "check_in_time":'checkInTime',
        "check_in_to_time":'checkInToTime',
        "check_out_time":'checkOutTime',
        "policy":'policy',
        "location":'location',
        "tax_number":'taxNumber',
        "tourist_license_number":'touristLicenseNumber',
        "tourist_license_expiry_date":'touristLicenseExpiryDate',
        "multi_unit":'multiUnit',
        "parent_id":'parentId'
    }

    def __init__(self,
                 name=None,
                 rooms=None,
                 bathrooms=None,
                 persons=None,
                 property_type=None,
                 currency=None,
                 supported_los_rates=None,
                 id=None,
                 alt_id=None,
                 supplier_id=None,
                 toilets=None,
                 total_beds=None,
                 space=None,
                 space_unit=None,
                 childs=None,
                 latitude=None,
                 longitude=None,
                 living_room=None,
                 notes=None,
                 attributes_with_quantity=None,
                 nearby_amenities=None,
                 bedroom_configuration=None,
                 check_in_time=None,
                 check_in_to_time=None,
                 check_out_time=None,
                 policy=None,
                 location=None,
                 tax_number=None,
                 tourist_license_number=None,
                 tourist_license_expiry_date=None,
                 multi_unit=None,
                 parent_id=None):
        """Constructor for the Property class"""

        # Initialize members of the class
        self.name = name
        self.id = id
        self.alt_id = alt_id
        self.supplier_id = supplier_id
        self.rooms = rooms
        self.bathrooms = bathrooms
        self.toilets = toilets
        self.total_beds = total_beds
        self.space = space
        self.space_unit = space_unit
        self.persons = persons
        self.childs = childs
        self.latitude = latitude
        self.longitude = longitude
        self.living_room = living_room
        self.notes = notes
        self.attributes_with_quantity = attributes_with_quantity
        self.nearby_amenities = nearby_amenities
        self.property_type = property_type
        self.bedroom_configuration = bedroom_configuration
        self.check_in_time = check_in_time
        self.check_in_to_time = check_in_to_time
        self.check_out_time = check_out_time
        self.currency = currency
        self.policy = policy
        self.location = location
        self.supported_los_rates = supported_los_rates
        self.tax_number = tax_number
        self.tourist_license_number = tourist_license_number
        self.tourist_license_expiry_date = tourist_license_expiry_date
        self.multi_unit = multi_unit
        self.parent_id = parent_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        rooms = dictionary.get('rooms')
        bathrooms = dictionary.get('bathrooms')
        persons = dictionary.get('persons')
        property_type = dictionary.get('propertyType')
        currency = dictionary.get('currency')
        supported_los_rates = dictionary.get('supportedLosRates')
        id = dictionary.get('id')
        alt_id = dictionary.get('altId')
        supplier_id = dictionary.get('supplierId')
        toilets = dictionary.get('toilets')
        total_beds = dictionary.get('totalBeds')
        space = dictionary.get('space')
        space_unit = dictionary.get('spaceUnit')
        childs = dictionary.get('childs')
        latitude = dictionary.get('latitude')
        longitude = dictionary.get('longitude')
        living_room = dictionary.get('livingRoom')
        notes = apimaticcalculatorlatest.models.notes.Notes.from_dictionary(dictionary.get('notes')) if dictionary.get('notes') else None
        attributes_with_quantity = None
        if dictionary.get('attributesWithQuantity') != None:
            attributes_with_quantity = list()
            for structure in dictionary.get('attributesWithQuantity'):
                attributes_with_quantity.append(apimaticcalculatorlatest.models.attributes_with_quantity.AttributesWithQuantity.from_dictionary(structure))
        nearby_amenities = None
        if dictionary.get('nearbyAmenities') != None:
            nearby_amenities = list()
            for structure in dictionary.get('nearbyAmenities'):
                nearby_amenities.append(apimaticcalculatorlatest.models.nearby_amenity.NearbyAmenity.from_dictionary(structure))
        bedroom_configuration = apimaticcalculatorlatest.models.bedroom_configuration.BedroomConfiguration.from_dictionary(dictionary.get('bedroomConfiguration')) if dictionary.get('bedroomConfiguration') else None
        check_in_time = dictionary.get('checkInTime')
        check_in_to_time = dictionary.get('checkInToTime')
        check_out_time = dictionary.get('checkOutTime')
        policy = apimaticcalculatorlatest.models.policy.Policy.from_dictionary(dictionary.get('policy')) if dictionary.get('policy') else None
        location = apimaticcalculatorlatest.models.location.Location.from_dictionary(dictionary.get('location')) if dictionary.get('location') else None
        tax_number = dictionary.get('taxNumber')
        tourist_license_number = dictionary.get('touristLicenseNumber')
        tourist_license_expiry_date = dateutil.parser.parse(dictionary.get('touristLicenseExpiryDate')).date() if dictionary.get('touristLicenseExpiryDate') else None
        multi_unit = dictionary.get('multiUnit')
        parent_id = dictionary.get('parentId')

        # Return an object of this model
        return cls(name,
                   rooms,
                   bathrooms,
                   persons,
                   property_type,
                   currency,
                   supported_los_rates,
                   id,
                   alt_id,
                   supplier_id,
                   toilets,
                   total_beds,
                   space,
                   space_unit,
                   childs,
                   latitude,
                   longitude,
                   living_room,
                   notes,
                   attributes_with_quantity,
                   nearby_amenities,
                   bedroom_configuration,
                   check_in_time,
                   check_in_to_time,
                   check_out_time,
                   policy,
                   location,
                   tax_number,
                   tourist_license_number,
                   tourist_license_expiry_date,
                   multi_unit,
                   parent_id)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import apimaticcalculatorlatest.models.myield

class TransportYield(object):

    """Implementation of the 'TransportYield' model.

    TODO: type model description here.

    Attributes:
        product_id (int): ID of the product
        weekend (list of Yield): Set a specific date range in which you would
            like to manipulate the basic price per night on weekends.  For
            example you will set the YMR date range from 01.07.2016-31.07.2016
            param - (Friday, Saturday=0; Saturday, Sunday=1) yield amount = 20
            modifier - Increase Percent Price per night in the period from
            01.07.2016 to 31.07.2016 will be 100 USD in working days and 100 +
            20% = 120 USD in weekends (Friday, Saturday or Saturday, Sunday,
            depending on what was selected).
        length_of_stay (list of Yield): Automatically applies price
            modifications to inquiries based on the number of nights the
            inquiries are for.  For example you will set the YMR date range
            from 01.07.2016-31.07.2017 param - {Length of Stay}. Let’s say you
            set 15 days. yield amount = 5 modifier - Decrease Percent Price
            per night if you made a reservation for 15 or more days will be
            100 - 5% = 95 USD
        date_range (list of Yield): Set a specific date range in which you
            would like to manipulate the basic price per night.  For example
            you will set the YMR date range from 01.07.2016-31.07.2016 yield
            amount = 20 modifier - Increase Percent Price per night in the
            period from 01.07.2016 to 31.07.2016 will be 100 + 20% = 120 USD

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_id":'productId',
        "weekend":'weekend',
        "length_of_stay":'lengthOfStay',
        "date_range":'dateRange'
    }

    def __init__(self,
                 product_id=None,
                 weekend=None,
                 length_of_stay=None,
                 date_range=None):
        """Constructor for the TransportYield class"""

        # Initialize members of the class
        self.product_id = product_id
        self.weekend = weekend
        self.length_of_stay = length_of_stay
        self.date_range = date_range


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        product_id = dictionary.get('productId')
        weekend = None
        if dictionary.get('weekend') != None:
            weekend = list()
            for structure in dictionary.get('weekend'):
                weekend.append(apimaticcalculatorlatest.models.myield.Yield.from_dictionary(structure))
        length_of_stay = None
        if dictionary.get('lengthOfStay') != None:
            length_of_stay = list()
            for structure in dictionary.get('lengthOfStay'):
                length_of_stay.append(apimaticcalculatorlatest.models.myield.Yield.from_dictionary(structure))
        date_range = None
        if dictionary.get('dateRange') != None:
            date_range = list()
            for structure in dictionary.get('dateRange'):
                date_range.append(apimaticcalculatorlatest.models.myield.Yield.from_dictionary(structure))

        # Return an object of this model
        return cls(product_id,
                   weekend,
                   length_of_stay,
                   date_range)





# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class MultiUnitEnum(object):

    """Implementation of the 'MultiUnitEnum' enum.

    Enum for product multyunit type.

    Attributes:
        MLT: TODO: type description here.
        OWN: TODO: type description here.

    """

    MLT = 'MLT'

    OWN = 'OWN'




# -*- coding: utf-8 -*-

"""
    apimaticcalculatorlatest

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from apimaticcalculatorlatest.api_helper import APIHelper
from apimaticcalculatorlatest.configuration import Configuration
from apimaticcalculatorlatest.controllers.base_controller import BaseController
from apimaticcalculatorlatest.http.auth.custom_query_auth import CustomQueryAuth
from apimaticcalculatorlatest.models.get_p_mslist import GetPMslist
from apimaticcalculatorlatest.models.property_managerdetailsresponse import PropertyManagerdetailsresponse

class PropertyManagersController(BaseController):

    """A Controller to access Endpoints in the apimaticcalculatorlatest API."""


    def get_p_mslist(self):
        """Does a GET request to /pmlist.

        This API call will return a list of property managers (PM) that have
        been created in the BookingPal platform that is associated with your
        PMS.
        In all requests in this API section, you need to use your PMS
        credentials.

        Returns:
            GetPMslist: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/pmlist'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetPMslist.from_dictionary)

    def update_property_managerdetails(self,
                                       content_type,
                                       body,
                                       id):
        """Does a PUT request to /pm/{id}.

        This function will update a property manager’s details. In case of an
        update you do not need to pass all information, but if you have values
        in one section - all fields inside are mandatory.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (CreatenewUpdatePropertyManagerRequest): TODO: type
                description here. Example: 
            id (string): Property Manager ID

        Returns:
            PropertyManagerdetailsresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/pm/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'id': id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, PropertyManagerdetailsresponse.from_dictionary)

    def createnew_property_manager(self,
                                   content_type,
                                   body):
        """Does a POST request to /pm.

        This API call will allow the PMS to pass all data to BookingPal that
        is required for registering a new PM (Property Manager). All fields
        are mandatory - PMS must pass this data in order for a PM account to
        be created. You need to use PMS credentials for this request.

        Args:
            content_type (string): TODO: type description here. Example: 
            body (CreatenewUpdatePropertyManagerRequest): TODO: type
                description here. Example: 

        Returns:
            PropertyManagerdetailsresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/pm'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, PropertyManagerdetailsresponse.from_dictionary)

    def get_property_managerdetaildata(self,
                                       content_type,
                                       id):
        """Does a GET request to /pm/{id}.

        This function will return a property manager’s details that belong to
        the current user. You need to use your PMS API credentials. 
        Request Body parameters are the same as for creating PM.
        Response is the same as in creating a Property Manager function. Here
        you do not need to pass all root level fields, but if some are used -
        all fields inside are mandatory:
        - in CompanyDetails Model you can pass any field, and none of them is
        mandatory
        - in Policies Model - you can pass any field,  and none of them is
        mandatory
        - if you do use PaymentPolicy - all fields inside are mandatory
        - if you do use CancellationPolicy - all fields inside are mandatory
        - if you use Payment Model - all fields inside are mandatory

        Args:
            content_type (string): TODO: type description here. Example: 
            id (string): Property Manager ID

        Returns:
            PropertyManagerdetailsresponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/pm/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'id': id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'Content-Type': content_type
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        CustomQueryAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, PropertyManagerdetailsresponse.from_dictionary)
